package com.pfc.Info;

import java.io.Serializable;
import android.location.Location;


public class GeoNodo implements Serializable {

	// Serializable UID
	private static final long serialVersionUID = -9121943636715457236L;

	private Integer mId;
	private Double  mRadius;
	private String  mSince;
	
	private Double mLatitude;
	private Double mLongitude;
	private Double mAltitude;
	private String mPosition_since;
	
	private String mUsername;
	private Integer mUser_id;
	
	private ExtenalInfo mExtInfo;
	
	/**
     * Constructor used to create this object. 
     * @param id Identifier of social network (can be 0)
     * @param latitude The latitude of the node position 
     * @param longitude The longitude of the node position
     * @param altitude The Altitude of the node posicion
     * @param radius The radius/error of the node position
     * @param since The time when the node was created
     */

	public GeoNodo(Integer id, Double latitude, Double longitude, Double altitude, Double radius, String since, 
			String position_since)
	{
		super();
		mId = id;
		mRadius = radius;	
		
		
		mLatitude = latitude;
		mLongitude = longitude;
		mAltitude = altitude;
		mPosition_since = position_since;

		mSince = since;
		
		mExtInfo=null;
	}
	
	/**
     * Return the Identifier asociated to social network
     */
	
	public Integer getId() {
		return mId;
	}
	
	/**
     * Return the latitude of the node
     */
	public Double getLatitude() {
		return mLatitude;
	}
	
	/**
     * Return the longitude of the node
     */
	public Double getLongitude() {
		return mLongitude;
	}
	
	/**
     * Return the altitude of the node
     */
	public Double getAltitude(){
		return mAltitude;
	}
	
	/**
     * Return the radius of the node
     */
	public Double getRadius() {
		return mRadius;
	}
	
	public String getPosition_since(){
		return mPosition_since;
	}
	
	/**
     * Set the latitude of the node
     * 
     * @param latitude The latitude of the position node
     */
	public void setLatitude(Double latitude){
		mLatitude = latitude;
		getLocation();
	}
	
	/**
     * Set the longitude of the node
     * 
     * @param longitude The latitude of the position node
     */
	public void setLongitude(Double longitude){
		mLongitude = longitude;
		getLocation();
	}
	
	
	public Location getLocation ()
	{
		Location myLocation = new Location ("gps");
		myLocation.setLatitude(mLatitude);
		myLocation.setLongitude(mLongitude);
		myLocation.setAltitude(mAltitude);
		
		return myLocation;
	}
	
	
	public void setAltitude(float altitude){
		mAltitude = (double) altitude;
		getLocation();
	}
	
	public void setSince (String since)
	{
		mSince = since;
	}
	
	public String getSince ()
	{
		return mSince;
	}
	
	public void setExternalInfo (ExtenalInfo extInfo)
	{
		mExtInfo = extInfo;
	}
	
	public ExtenalInfo getExternalInfo ()
	{
		return mExtInfo;
	}
	
	public void setId(Integer id){
		mId = id;
	}

	public void setRadius(Double radius){
		mRadius = radius;
	}
	
	public void setPosition_since(String position_since){
		mPosition_since = position_since;
	}
	
	//uploader info
	public void setUser_id(Integer user_id){
		mUser_id = user_id;
	}
	
	public void setUsername(String username){
		mUsername = username;
	}
	
	public String getUsername(){
		return mUsername;
	}
	
	public Integer getUser_id(){
		return mUser_id;
	}
}
